==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectedValueChangedEventArgsDescriptionMetadata, _super);
    function SelectedValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
            SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Date");
        a.item("NewValue", "Date");
    };
    SelectedValueChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedValueChangedEventArgsDescriptionMetadata.b(a);
        a.u("SelectedValueChangedEventArgs", function () { return new SelectedValueChangedEventArgsDescription(); });
        a.t("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.$t = markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectedValueChangedEventArgsDescriptionMetadata, _super);
    function SelectedValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
            SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Date");
        a.item("NewValue", "Date");
    };
    SelectedValueChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("SelectedValueChangedEventArgs", function () { return new SelectedValueChangedEventArgsDescription(); });
        a.z("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.$t = markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedValueChangedEventArgsDescriptionMetadata };
